@@ -1,5 +1,5 @@
-/**
- * Copyright 2006-2017 the original author or authors.
+/*
+ * Copyright 2006-2018 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,16 +15,17 @@
  */
 package org.objenesis.tck.android;
 
-import android.app.Activity;
-import android.app.Instrumentation;
-import android.os.Bundle;
-import org.objenesis.tck.Main;
-import org.objenesis.tck.TextReporter;
-
 import java.io.ByteArrayOutputStream;
 import java.io.IOException;
 import java.io.PrintStream;
 
+import org.objenesis.tck.Main;
+import org.objenesis.tck.TextReporter;
+
+import android.app.Activity;
+import android.app.Instrumentation;
+import android.os.Bundle;
+
 /**
  * Wraps the Objenesis TCK so that it can be invoked on Android as an {@link Instrumentation}.
  *
@@ -53,10 +54,6 @@ public class TckInstrumentation extends Instrumentation {
 
    private void launch() throws IOException {
       TextReporter reporter = new TextReporter(System.out, System.err);
-
-      boolean parentConstructorTestSuccessful = Main.run(reporter);
-
-      reporter.printResult(parentConstructorTestSuccessful);
-
+      Main.run(reporter);
    }
 }
